<template>
  <div class='container'>
    <a-card :bordered='false'>
      <!-- 查询区域 -->
      <div class='table-page-search-wrapper'>
        <a-form layout='inline' @keyup.enter.native='searchQuery'>
          <a-row :gutter='24'>
            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
              <a-form-item label='项目日期'>
                <a-range-picker
                  v-model='queryParam.dateRange'
                  format='YYYY-MM-DD'
                  :placeholder="['开始日期', '结束日期']"
                  @change='onDateChange'>
                </a-range-picker>
              </a-form-item>
            </a-col>

            <a-col :md='6' :sm='12'>
              <a-form-item label='负责组'>
                <j-search-select-tag
                  placeholder='请选择负责组别'
                  v-model='queryParam.xmfzz'
                  dict='sys_depart,depart_name,id'
                  :pageSize='1000'
                  :async='true'>
                </j-search-select-tag>
              </a-form-item>
            </a-col>

            <a-col :md='6' :sm='12'>
              <a-form-item label='负责人'>
                <j-search-select-tag
                  placeholder='请选择负责人'
                  v-model='queryParam.xmfzr'
                  dict='sys_user,realname,username'
                  :pageSize='10'
                >
                </j-search-select-tag>
              </a-form-item>
            </a-col>


            <template v-if='toggleSearchStatus'>
              <a-col :md='6' :sm='12'>
                <a-form-item label='里程碑'>
                  <j-dict-select-tag
                    placeholder='请选择项目里程碑'
                    dictCode='lcb'
                    v-model='queryParam.lcb'
                  />
                </a-form-item>
              </a-col>

              <a-col :md='6' :sm='12'>
                <a-form-item label='当前阶段'>
                  <j-dict-select-tag
                    placeholder='请选择项目当前阶段'
                    dictCode='dqjd'
                    v-model='queryParam.dqjd'
                  />
                </a-form-item>
              </a-col>

              <a-col :md='6' :sm='12'>
                <a-form-item label='项目状态'>
                  <j-dict-select-tag
                    placeholder='请选择项目状态'
                    dictCode='xmzt'
                    v-model='queryParam.xmzt'
                  />
                </a-form-item>
              </a-col>
            </template>

            <a-col :md='6' :sm='8'>
            <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
              <a-button type='primary' @click='searchQuery' icon='search'>查询</a-button>
              <a-button type='primary' @click='searchReset' icon='reload' style='margin-left: 8px'>重置</a-button>
              <a @click='handleToggleSearch' style='margin-left: 8px'>
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
            </a-col>


            <!--            <a-col :xl='6' :lg='7' :md='8' :sm='24'>
                          <a-form-item label='批次号'>
                            <a-select placeholder='请选择批次' v-model='batch'>
                              <a-select-option v-for='(item,index) in batchOptions' :key='index' :value='item.value'>{{ item.text
                                }}
                              </a-select-option>
                            </a-select>
                          </a-form-item>
                        </a-col>-->

          </a-row>
        </a-form>
      </div>
      <!-- 查询区域-END -->
      <iframe ref='report' class='report'></iframe>
    </a-card>


  </div>
</template>

<script>

import moment from 'moment'
import { getAction } from '@api/manage'

export default {
  name: 'ProjectListReport',
  data() {
    return {
      moment,
      dateFormat: 'YYYY-MM-DD',
      /* 查询折叠 */
      toggleSearchStatus: false,
      queryParam: {
        dateRange: [
          moment().startOf('year').format('YYYY-MM-DD'),
          moment().subtract(0, 'days').format('YYYY-MM-DD')
        ]
      },
      batch: null,
      batchOptions: [],
      url: {
        batchList: '/lims/testing/batch/list'
      }
    }
  },
  mounted() {


  },
  created() {
    this.queryParam.ksrq = moment().startOf('year').format('YYYY-MM-DD')
    this.queryParam.jsrq = moment().subtract(0, 'days').format('YYYY-MM-DD')

    setTimeout(()=>{
      this.searchQuery()
    },500)


  },
  methods: {
    handleToggleSearch() {
      this.toggleSearchStatus = !this.toggleSearchStatus
    },
    onDateChange: function(value, dateString) {
      this.queryParam.ksrq = dateString[0]
      this.queryParam.jsrq = dateString[1]
      this.$forceUpdate()
      console.info(this.queryParam)
    },
    searchQuery() {
      let url = this.reportUrl
      let params = Object.assign({}, this.queryParam)
      if (params.dateRange) {
        delete params.dateRange
      }
      console.info(this.queryParam.dateRange)
      params.ksrq =  params.ksrq + ' 00:00:00'
      params.jsrq =  params.jsrq + ' 23:59:59'
      for (let key in params) {
        if (key && params[key])
          url = url + '&' + key + '=' + params[key]
      }
      this.$refs.report.src = url
      console.info(url)

    },
    searchReset() {
      this.queryParam = {
        dateRange: [
          moment().startOf('year').format('YYYY-MM-DD'),
          moment().subtract(0, 'days').format('YYYY-MM-DD')
        ]
      }
      this.queryParam.ksrq = moment().startOf('year').format('YYYY-MM-DD')
      this.queryParam.jsrq = moment().subtract(0, 'days').format('YYYY-MM-DD')
      this.searchQuery()
    }

  },
  computed: {
    reportUrl: function() {
      return `${window._CONFIG['domianREPORT']}/report/reportJsp/showReport.jsp?rpx=ylb.rpx`
    }
  }
}
</script>

<style lang='less' scoped>
.container {
  width: 100%;
  height: 120vh;
  z-index: 10;
}

.report {
  width: 100%;
  height: 100vh;
  border: none;
}

</style>